%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% COUNTERFACTUAL OVER TIME (Figure A4)

%%% First run mainMLE.m and mainMLEmultdest.m to generate ML Estimates
%%% written into THETA_MLE.csv, THETA_MLEmd.csv, THETA_MLEmd_alt.csv
%%% Then run COUNTERFACTUALmult.m and after this code



%% Load data across years



DATAMOM=[];

for yr=1986:1998

    ddd = csvread(sprintf('%s%d%s','/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-',yr,'-fun.csv'));
    HHH = log(ddd(:,10));    % log employment
    WWW = ddd(:,8);          % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
    III = ddd(:,9);          % export status (dummy for exporter)
    N = size(ddd,1);
       
    varW = mean(WWW.^2 .* exp(HHH))/mean(exp(HHH)) - (mean( (WWW) .* exp(HHH))/mean(exp(HHH)))^2;
     
    % DATA: fraction exporters, exporter employment share and st.dev of log worker wages
    DATAMOM = [DATAMOM; [mean(III) sum(III'*exp(HHH))/sum(exp(HHH)) sqrt(varW)]];
    
end



%% Variation in variable trade cost tau to match exporter employment share in the data

XSHY = DATAMOM(:,2)+0.4324-.5175;
XSHY2 = DATAMOM(:,2)+0.5127-.5175;
INEQY = zeros(size(XSHY));
INEQY2 = zeros(size(XSHY));
for t=1:13
    ik = find(DATA(:,1)-XSHY(t)>0,1);
    INEQY(t) = ( - DATA(ik,2)*(DATA(ik-1,1)-XSHY(t)) + DATA(ik-1,2)*(DATA(ik,1)-XSHY(t)) ) / (DATA(ik,1)-DATA(ik-1,1) ) ;
    
    ik2 = find(DATA(:,7)-XSHY2(t)>0,1);
    INEQY2(t) = ( - DATA(ik2,10)*(DATA(ik2-1,7)-XSHY2(t)) + DATA(ik2-1,10)*(DATA(ik2,7)-XSHY2(t)) ) / (DATA(ik2,7)-DATA(ik2-1,7) ) ;
end



%% Resulting inequality dynamics (Figure A4 in the paper)

figure(24)
plot((1986:1998)',INEQY/INEQY(9),'-o',(1986:1998)',INEQY2/INEQY2(9),'--s','linewidth',2)
% legend('Baseline','Multi-destination','location','northwest','FontSize',14,'interpreter','latex')
hold on
% plot((1986:1998)',DATAMOM(:,3)/DATAMOM(9,3),'-.d')
text(1986.5,0.998,'Baseline','FontSize',16,'interpreter','latex')
text(1986.1,0.986,'Multi-','FontSize',14,'interpreter','latex')
text(1986.1,0.9845,'destination','FontSize',14,'interpreter','latex')
plot([1986 1998],[1 1],'k:','linewidth',1)
plot([1990 1990],[.97 1.015],'k:')
plot([1994 1994],[.97 1.015],'k:')
axis([1986 1998 .97 1.015])
set(gca,'FontSize',14)
set(gca,'ytick',[.97:.01:1.01])

print -depsc CounterfactualOverTime.eps