%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% MAIN CODE FOR STRUCTURAL MAXIMUM LIKELIHOOD ESTRIMATION

clear all
% close all
clc
cd '/home/sjredding/himr-restud/matlab/brazil'

global K izt isu isv iru irv imh imw ifx X T eps MMM


%% ------ PARAMETERS ------
K = 8;   % number of parameters to estimate

% indexes of the estimated parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f

eps = 1e-8; % precision
MMM = 1e+5; % upper bounds

% Parameter lower and upper bounds
LB0 = [-1 eps eps -3 -3 -5 -5 -5]';
UB0 = [1 25 25 3 3 5 5 5]';



%% ------ ESTIMATION ------

T = 1998-1986+1;        % number of years for estimation
yr = 1986-1;            % initial year for estimation
THETA_MLE = zeros(K,T); % matrix of estimated parameters

for t = 1:T
    yr = yr + 1
    
    %% --- LOAD DATA X --- 
    if yr==1986;     data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1986-fun.csv');
    elseif yr==1987; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1987-fun.csv');
    elseif yr==1988; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1988-fun.csv');
    elseif yr==1989; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1989-fun.csv');
    elseif yr==1990; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1990-fun.csv');
    elseif yr==1991; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1991-fun.csv');
    elseif yr==1992; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1992-fun.csv');
    elseif yr==1993; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1993-fun.csv');
    elseif yr==1994; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');
    elseif yr==1995; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1995-fun.csv');
    elseif yr==1996; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1996-fun.csv');
    elseif yr==1997; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1997-fun.csv');
    elseif yr==1998; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1998-fun.csv');
    end
    %     Columns in firm-year data;

    % Column 1 : cnpj_radic; 
    % Column 2 : firm_subsibge; 
    % Column 3 : year; 
    % Column 4 : lwageyr;   
    % Column 5 : wageyr; 
    % Column 6 : reslwageyr; 
    % Column 7 : obslwageyr; 
    % Column 8 : felwageyr; 
    % Column 9 : indexp; 
    % Column 10 : employ; 
    % Column 11 : indimp; 
    % Column 12 : indexpusa; 
    % Column 13 : meso; 
    % Column 14 : state; 
    % Column 15 : lwageyrmeso; 
    % Column 16 : felwageyrmeso; 
    % Column 17 : lemploymeso;
    % Column 18 : indexpbin1; 
    % Column 19 : indexpbin2; 
    % Column 20 : indexpbin3; 
    % Column 21 : forworker;
    % Column 22 : nexpbin1; 
    % Column 23 : nexpbin2; 
    % Column 24 : nexpbin3;

    N = size(data,1);       % number of observations (firms)
    I = data(:,9);       % export status (dummy for exporter)
    H = log(data(:,10));  % log employment
    W = data(:,8);        % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
    X = [H W I];            % data matrix
    

    %% --- INITIAL CONDITION --- 
    % ML parameters under restricted model with mu_h = mu_w = rho_u = rho_v = 0
    COVM = cov(X);
    Theta0 = [COVM(2,1)/COVM(1,1) std(H) std(W) 0 0 0 0 norminv(mean(1-I),0,1)]';
        
    %% --- ESTIMATION --- 
    
    % Optimization options
    options = optimset('display','iter','TolFun',eps,'TolX',eps);
       
    % Transformed initial conditions (see appendix)
    Theta0_tr = Theta0;
    Theta0_tr([isu; isv]) = Theta0([isu; isv]).^2;
    Theta0_tr([iru; irv; ifx]) = Theta0([iru; irv; ifx])/sqrt(max(eps,1 - Theta0(iru)^2 - Theta0(irv)^2));
    
    % Constrained optimization 
    % see llf.m for the objective (-log-likelihood) function 
    % see strconstr.m for the structural constraint
    % The structural MLE is estimated using the equality constraint.
    % We check manually that the maximum likelihood is attained at the 
    % corner when the structural inequality constraint is imposed.
    [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
        = fmincon('llf',Theta0_tr,[],[],[],[],LB0,UB0,'strconstr',options);
    
    % Reverse transformation
    Theta_mle = Theta_mle_tr;
    Theta_mle([isu; isv]) = sqrt(Theta_mle_tr([isu; isv]));
    Theta_mle([iru; irv; ifx]) = Theta_mle_tr([iru; irv; ifx]) ...
        /sqrt(1 + Theta_mle_tr(iru)^2 + Theta_mle_tr(irv)^2);

    THETA_MLE(:,t) = Theta_mle;
    
end

% Save estimate parameters:
dlmwrite('THETA_MLE.csv',THETA_MLE,'precision','%14.6f','newline','pc');

%% Column (1) of Table 4 in the paper
display('1994 Parameter Estimates');
display('mu_h');
THETA_MLE(6,9)
display('mu_w');
THETA_MLE(7,9)
display('rho_u');
THETA_MLE(4,9)
display('rho_v');
THETA_MLE(5,9)
display('f');
THETA_MLE(8,9)


%% Use VML_c.m to calculate standard errors and plot the parameter estimates 
% % Table 4 and Figure A1 in the paper
% VML_c.m


%% Use main_moments.m to calculate moments in the estimated model
% % Tables 5-7 and Figure A2 in the paper
% main_moments.m


%% Use COUNTERFACTUAL.m for MLE counterfactual analysis
% % Figure 1 in the paper
% COUNTERFACTUAL.m
% % Also run ROBUSTENESSovertime.m to generate Figure H.10 (panels a and b) in the Online Supplement
% ROBUSTENESSovertime.m


%% Use GMMBounds.m for GMM Bounds ESTIMATION and COUNTERFACTUALS
% % Figure A3 in the paper with ID Set
% GMMBounds.m
% % Figure 2 in the paper with GMM Bounds Counterfactuals
% % USE GMMBoundsCounterfactualAutarky.m for Left Figure 2 (autarky counterfactual)
% % USE GMMBoundsCounterfactualLocal.m for Right Figure 2 (local 10% counterfactual)
% GMMBoundsCounterfactualAutarky.m
% GMMBoundsCounterfactualLocal.m


%% Use mainMLEmultdest.m for multi-sector estimation 
%% Use COUNTERFACTUALmult.m for multi-sector counterfactuals
% % Figure 3 and Table A3 in the paper
% mainMLEmultdest.m       % (uses functions llf_md.m and strconstr_md.m)
% COUNTERFACTUALmult.m
% % Use COUNTERFACTUALovertime.m to generate Figure A4 in the paper
% COUNTERFACTUALovertime.m