clear
clear matrix
program drop _all
set more off
set virtual on
set mem 100m
set trace off
set matsize 150

// check temporary directory
! export STATATMP=/u/data/tmp
tempfile findout
* disp "`findout'"
if substr("`findout'",1,12)~="/u/data/tmp/"  STOP  // default /tmp/ too small to use

global dofiles "/u/data/himr/code/stata/dofiles"
global logs    "/u/data/himr/code/stata/logs/apdx"
global tex     "/u/data/himr/code/stata/tex"
global input   "/u/data/himr/input"
global data    "/u/data/himr/restud"
global rawdata "/u/data/rais"

cd "$data"
program drop _all
adopath + "/u/data/himr/code/ado/"
qui do "/u/data/himr/code/ado/%Read-tabl2tex.do"

capture mkdir "$logs"
capture mkdir "$tex"

* do "$dofiles/apdx/apdx-stats.do"
    /* DESCRIPTIVE STATISTICS FOR DATA APPENDIX */
    /* INPUT:  "$rawdata/base-ano/ano`year'.csv" (`year' in 1986/1998)
               "$input/rais-secex-all-workers-`year'.dta" (`year' in 1986/1998) */
    /* OUTPUT: "$tex/apdxstats.tex"
               "$tex/smplstats.tex"
               "$tex/expstats.tex" */
    /*    Log: "$logs/apdx-stats.log" */

* do "$dofiles/apdx/sec-occ.do"
    /* TABULATE CNAE SECTORS AND CBO OCCUPATIONS */
    /* INPUT:  "$input/rais-secex-all-workers-`year'.dta" (`year' in 1986-1998)
               "$rawdata/cnae/cnae_95.do"  */
    /* OUTPUT: . 
          TeX: "$tex/cbo.tex"
               "$tex/cnae.tex" */
    /*    Log: "$logs/sec-occ.log" */ 

* do "$dofiles/apdx/apdx-stats-samplecond.do"
    /* DESCRIPTIVE STATISTICS FOR DATA APPENDIX */
    /* INPUT:  "$input/rais-secex-all-workers-`year'.dta" (`year' in 1986/1998)
          DO:  "/u/data/himr/code/stata/dofiles/routines/samplecond.do" */
    /* OUTPUT: "$tex/apdxstats_sc.tex"
               "$tex/expstats_sc.tex" */
    /*    Log: "$logs/apdx-stats-samplecond.log" */

* do "$dofiles/apdx/sec-occ-samplecond.do"
    /* TABULATE CNAE SECTORS AND CBO OCCUPATIONS */
    /* INPUT:  "$input/rais-secex-all-workers-`year'.dta" (`year' in 1986-1998)
               "$rawdata/cnae/cnae_95.do"
          DO:  "/u/data/himr/code/stata/dofiles/routines/samplecond.do" */
    /* OUTPUT: . 
          TeX: "$tex/cbo_sc.tex"
               "$tex/cnae_sc.tex" */
    /*    Log: "$logs/sec-occ-samplecond.log" */ 
