*! version 1.1  12mar2012  by Marc Muendler     muendler@ucsd.edu
*! version 2.1  12apr2014  by Marc Muendler     muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set trace off
set more off
set mem 30g
set matsize 1000

cd "$root"

capture log close
log using "$logs/apdx-stats.log", replace
 

*** UNIVERSE

mat apdxstats = J(15,4,.)
mat rownames apdxstats = y1986 y1987 y1988 y1989 y1990 y1991 y1992 y1993 y1994 y1995 y1996 y1997 y1998 period mean
mat colnames apdxstats = spells workers plants firms

foreach year of numlist 1986(1)1998 {
tempfile yr`year'

insheet using "$rawdata/base-ano/ano`year'.csv", clear

* firm level (firm ID)
gen long cnpj_radic = int(identificad/1000000)
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

keep pis ano identificad cnpj_radic
count
mat apdxstats[rownumb(apdxstats,"y`year'"),colnumb(apdxstats,"spells")] = `r(N)'
sort pis
qui count if pis~=pis[_n-1]
mat apdxstats[rownumb(apdxstats,"y`year'"),colnumb(apdxstats,"workers")] = `r(N)'
sort identificad
qui count if identificad~=identificad[_n-1]
mat apdxstats[rownumb(apdxstats,"y`year'"),colnumb(apdxstats,"plants")] = `r(N)'
sort cnpj_radic
qui count if cnpj_radic~=cnpj_radic[_n-1]
mat apdxstats[rownumb(apdxstats,"y`year'"),colnumb(apdxstats,"firms")] = `r(N)'

sort pis ano identificad cnpj_radic
save `yr`year''

} // close `year' loop

use `yr1986'
foreach year of numlist 1987(1)1998 {
  append using `yr`year''
  }
count
mat apdxstats[rownumb(apdxstats,"period"),colnumb(apdxstats,"spells")] = `r(N)'
sort pis
qui count if pis~=pis[_n-1]
mat apdxstats[rownumb(apdxstats,"period"),colnumb(apdxstats,"workers")] = `r(N)'
sort identificad
qui count if identificad~=identificad[_n-1]
mat apdxstats[rownumb(apdxstats,"period"),colnumb(apdxstats,"plants")] = `r(N)'
sort cnpj_radic
qui count if cnpj_radic~=cnpj_radic[_n-1]
mat apdxstats[rownumb(apdxstats,"period"),colnumb(apdxstats,"firms")] = `r(N)'

mat rename apdxstats apdxstats_tbl
est2tex apdxstats, replace dropall ready p($tex) fancy
foreach var of varlist spells workers plants firms {
  qui summ `var' if _rowname~="period" & _rowname~="mean"
  mat apdxstats_tbl[rownumb(apdxstats_tbl,"mean"),colnumb(apdxstats_tbl,"`var'")] = `r(mean)'
  }
* qui summ spells
* mat apdxstats[rownumb(apdxstats,"period"),colnumb(apdxstats,"spells")] = `r(sum)'
est2tex apdxstats, replace dropall ready p($tex) fancy


*** SAMPLE

mat smplstats = J(15,4,.)
mat rownames smplstats = y1986 y1987 y1988 y1989 y1990 y1991 y1992 y1993 y1994 y1995 y1996 y1997 y1998 period mean
mat colnames smplstats = spells workers plants firms

foreach year of numlist 1986(1)1998 {
tempfile yr`year'

use pis firm_subsibge wageyr identificad cnpj_radic firm_indexp indprof indtech indwhit indsklb indunsklb using $input/rais-secex-all-workers-`year'.dta, clear
keep if firm_subsibge>=2 & firm_subsibge<=13
gen byte iscogrp = 5 if indprof==1
replace iscogrp = 4 if indtech==1
replace iscogrp = 3 if indwhit==1
replace iscogrp = 2 if indsklb==1
replace iscogrp = 1 if indunsklb==1
label var iscogrp "ISCO-88 Occupation group"
label define iscogrp 5 "Professional and Managerial occ." 4 "Technical and Supervisory occ occ." 3 "Other White Collar occ." 2 "Skill Intensive Blue Collar occ." 1 "Other Blue Collar occ.", modify
label values iscogrp iscogrp

* Drop observations with missing firm_subsibge code
drop if firm_subsibge==.

* DEFINE SAMPLE
drop if wageyr<=0
drop if wageyr==.

* Keep highest wage for each worker if more than one wage
gsort pis -wageyr
quietly by pis: gen _order=_n
tab _order
drop if _order>1
drop _order

gen int ano  = `year'
label var ano  "Calendar year"

keep pis ano identificad cnpj_radic firm_indexp iscogrp
count
mat smplstats[rownumb(smplstats,"y`year'"),colnumb(smplstats,"spells")] = `r(N)'
sort pis
qui count if pis~=pis[_n-1]
mat smplstats[rownumb(smplstats,"y`year'"),colnumb(smplstats,"workers")] = `r(N)'
sort identificad
qui count if identificad~=identificad[_n-1]
mat smplstats[rownumb(smplstats,"y`year'"),colnumb(smplstats,"plants")] = `r(N)'
sort cnpj_radic
qui count if cnpj_radic~=cnpj_radic[_n-1]
mat smplstats[rownumb(smplstats,"y`year'"),colnumb(smplstats,"firms")] = `r(N)'

sort pis ano identificad cnpj_radic
save `yr`year''

}  // close `year' loop

use `yr1986'
foreach year of numlist 1987(1)1998 {
  append using `yr`year''
  }
count
mat smplstats[rownumb(smplstats,"period"),colnumb(smplstats,"spells")] = `r(N)'
sort pis
qui count if pis~=pis[_n-1]
mat smplstats[rownumb(smplstats,"period"),colnumb(smplstats,"workers")] = `r(N)'
sort identificad
qui count if identificad~=identificad[_n-1]
mat smplstats[rownumb(smplstats,"period"),colnumb(smplstats,"plants")] = `r(N)'
sort cnpj_radic
qui count if cnpj_radic~=cnpj_radic[_n-1]
mat smplstats[rownumb(smplstats,"period"),colnumb(smplstats,"firms")] = `r(N)'

qui count
disp in gr "Workers 1986-1998: " in ye `r(N)'
qui count if firm_indexp==1
disp in gr "Exporter Workers 1986-1998: " in ye `r(N)'

preserve
  keep cnpj_radic iscogrp
  bysort cnpj_radic iscogrp: keep if _n==1
  qui count
  disp in gr "Firm-Occupation cells 1986-1998: " in ye `r(N)'
  keep cnpj_radic
  bysort cnpj_radic: keep if _n==1
  qui count
  disp in gr "Firms 1986-1998: " in ye `r(N)'
restore

mat rename smplstats smplstats_tbl
est2tex smplstats, replace dropall ready p($tex) fancy
foreach var of varlist spells workers plants firms {
  qui summ `var' if _rowname~="period" & _rowname~="mean"
  mat smplstats_tbl[rownumb(smplstats_tbl,"mean"),colnumb(smplstats_tbl,"`var'")] = `r(mean)'
  }
* qui summ spells
* mat smplstats[rownumb(smplstats,"period"),colnumb(smplstats,"spells")] = `r(sum)'
est2tex smplstats, replace dropall ready p($tex) fancy


*** EXPORTERS IN MANUFACTURING

mat expstats = J(15,2,.)
mat rownames expstats = y1986 y1987 y1988 y1989 y1990 y1991 y1992 y1993 y1994 y1995 y1996 y1997 y1998 period mean
mat colnames expstats = firms exporters

foreach year of numlist 1986(1)1998 {
tempfile yr`year'

use cnpj_radic firm_subsibge firm_indexp using $input/rais-secex-all-workers-`year'.dta, clear
keep if firm_subsibge>=2 & firm_subsibge<=13

* Drop observations with missing firm_subsibge code
drop if firm_subsibge==.
bysort cnpj_radic firm_subsibge: keep if _n==1
qui duplicates tag cnpj_radic, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP  // non-unique sector assignment to firm
drop _dupl 

gen int ano  = `year'
label var ano  "Calendar year"

count
mat expstats[rownumb(expstats,"y`year'"),colnumb(expstats,"firms")] = `r(N)'
summ firm_indexp
mat expstats[rownumb(expstats,"y`year'"),colnumb(expstats,"exporters")] = `r(sum)'

sort cnpj_radic ano
save `yr`year''

}  // close `year' loop

use `yr1986'
foreach year of numlist 1987(1)1998 {
  append using `yr`year''
  }
sort cnpj_radic
count if cnpj_radic~=cnpj_radic[_n-1]
mat expstats[rownumb(expstats,"period"),colnumb(expstats,"firms")] = `r(N)'
sort firm_indexp cnpj_radic
count if cnpj_radic~=cnpj_radic[_n-1] & firm_indexp==1
mat expstats[rownumb(expstats,"period"),colnumb(expstats,"exporters")] = `r(N)'

mat rename expstats expstats_tbl
est2tex expstats, replace dropall ready p($tex) fancy
foreach var of varlist firms exporters {
  qui summ `var' if _rowname~="period" & _rowname~="mean"
  mat expstats_tbl[rownumb(expstats_tbl,"mean"),colnumb(expstats_tbl,"`var'")] = `r(mean)'
  }
est2tex expstats, replace dropall ready p($tex) fancy

log close

