
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*********************************************************************;
**** This file aggregates the firm-occupation-year fixed effects ****;
**** to the firm-year level                                      ****;
*********************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global temp="/data/sjredding/himr-restud/tmp";

log using $logs/condwtvfe/mincer/agg-tmincer.log,replace;

*****************************************************************;
* Aggregate fun sector-occupations to occupations for each year *;
*****************************************************************;

#delimit;
set more off;
foreach yr of numlist 1986(1)1998 {;
clear;
u $data/condwtvfe/mincer/tmincer-`yr'-fun.dta;
local varlist="lwageyr wageyr felwageyr reslwageyr obslwageyr indexp* indimp ind10pls forworker";
collapse (mean) `varlist' [aw=employ], by(cnpj_radic firm_subsibge meso state year) fast;
so cnpj_radic year;
sa $temp/temp.dta, replace;

clear;
u $data/condwtvfe/mincer/tmincer-`yr'-fun.dta;
collapse (sum) employ, by(cnpj_radic firm_subsibge year) fast;
so cnpj_radic year;

merge 1:1 cnpj_radic year using $temp/temp.dta;
tab _m;
drop _m;

gen lemploy=ln(employ);

*******************;
* Transformations *;
*******************;

gen data=1;

egen noj=count(data),by(firm_subsibge meso year);
su noj, d;

egen lwageyrmeso=mean(lwageyr),by(firm_subsibge meso year);

egen felwageyrmeso=mean(felwageyr), by(firm_subsibge meso year);

egen lemploymeso=mean(lemploy),by(firm_subsibge meso year);

* Original export bins;

gen indexpbin1=0;
replace indexpbin1=1 if indexp0001==1;

gen indexpbin2=0;
replace indexpbin2=1 if indexp0105==1;
replace indexpbin2=1 if indexp0510==1;

gen indexpbin3=0;
replace indexpbin3=1 if indexp1015==1;
replace indexpbin3=1 if indexp1520==1;
replace indexpbin3=1 if indexp2025==1;
replace indexpbin3=1 if indexp2530==1;
replace indexpbin3=1 if indexp3040==1;
replace indexpbin3=1 if indexp4050==1;
replace indexpbin3=1 if indexp50==1; 

* New export bins;

gen nexpbin1=0;
replace nexpbin1=1 if indexp0001==1;
replace nexpbin1=1 if indexp0105==1;

gen nexpbin2=0;
replace nexpbin2=1 if indexp0510==1;
replace nexpbin2=1 if indexp1015==1;
replace nexpbin2=1 if indexp1520==1;
replace nexpbin2=1 if indexp2025==1;

gen nexpbin3=0;
replace nexpbin3=1 if indexp2530==1;
replace nexpbin3=1 if indexp3040==1;
replace nexpbin3=1 if indexp4050==1;
replace nexpbin3=1 if indexp50==1; 

destring state, replace;

lab var forworker       "Fraction of firm's employees within an occupation that are foreign";

local varlist1="cnpj_radic firm_subsibge year lwageyr wageyr reslwageyr obslwageyr felwageyr indexp employ indimp indexpusa meso state lwageyrmeso felwageyrmeso lemploymeso";
local varlist2="indexpbin1 indexpbin2 indexpbin3 forworker nexpbin1 nexpbin2 nexpbin3";

order `varlist1' `varlist2'; 

so cnpj_radic year;
sa $data/condwtvfe/mincer/agg-tmincer-`yr'-fun.dta, replace;

outsheet `varlist1' `varlist2' `varlist3' using $data/condwtvfe/mincer/agg-tmincer-`yr'-fun.csv, comma nonames nolabel replace;

};

*************************************************************;
* Aggregate sector-occupations to occupations for all years *;
*************************************************************;

u $data/condwtvfe/mincer/agg-tmincer-1986-fun.dta;
foreach yr of numlist 1987(1)1998 {;
append using $data/condwtvfe/mincer/agg-tmincer-`yr'-fun.dta;
};

so cnpj_radic year;
sa $data/condwtvfe/mincer/agg-tmincer-all-fun.dta, replace;

****************************;
* Dataset with sample size *;
****************************;

u $data/condwtvfe/mincer/agg-tmincer-all-fun.dta, clear;
isid cnpj_radic year;
gen firms=1;
codebook state;
codebook meso;
collapse (sum) firms employ, by(year) fast;
gen aveemp=employ/firms;
so year;
sa $data/condwtvfe/mincer/agg-tmincer-all-fun-sample.dta, replace;

log close;
