
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s1color;

**************************************************************;
**** This file estimates semi-parametric selection models ****;
**************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/condwtvfe/mincer/semi-parametric-iv.log, replace;

*******************************;
**** Get firm_cnae95 codes ****;
*******************************;

#delimit;
use $input/rais-secex-all-workers-1994.dta, clear;
gen data=1;
keep cnpj_radic firm_cnae95 data;
collapse (first) data, by(cnpj_radic firm_cnae95) fast;
drop data;
so cnpj_radic firm_cnae95;
sa $data/condwtvfe/mincer/cnpj_radic_cnae95_1994.dta, replace;

****************************************************;
**** Clean up firm_cnae95-meso mass layoff data ****;
****************************************************;

u $input/meso-mass-layoff-cnae.dta, clear;
keep if year==1994;
ren cnae firm_cnae95;
so firm_cnae95 meso;
sa $data/tradeinst/meso-mass-layoff-cnae-1994-clean.dta, replace;

*****************************;
**** Semi-parameteric IV ****;
*****************************;

#delimit;
* Use data;
u $data/condwtvfe/mincer/agg-tmincer-1994-fun.dta, clear;
isid cnpj_radic;
so cnpj_radic;

* merge CNAE95 codes;

merge 1:1 cnpj_radic using $data/condwtvfe/mincer/cnpj_radic_cnae95_1994.dta;
tab _m;
keep if _m==1|_m==3;
tab _m;
drop _m;

codebook cnpj_radic;

**********************************************;
* Merge doing business exporting instruments *;
**********************************************;

so cnpj_radic year;
merge 1:1 cnpj_radic year using $data/tradeinst/firms-1994-hs6-dobusi.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
so cnpj_radic year;

***************************************;
**** Merge meso region instruments ****;
***************************************;

isid meso year cnpj_radic;
so meso year cnpj_radic;
merge m:1 meso year using $data/nationality/meso-for-workers-all.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;

**********************************************************;
**** Use firm_cnae95-meso foreign worker mass layoffs ****;
**********************************************************;

so firm_cnae95 meso cnpj_radic;
merge m:1 firm_cnae95 meso using /data/sjredding/tradeinst/meso-mass-layoff-cnae-1994-clean.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;

************************************************;
**** Clean meso foreign worker mass layoffs ****;
************************************************;

replace indnonbraz=0 if indnonbraz==.;

egen cnaemeso=group(firm_cnae95 meso);

*********************************************************;
**** Normalize variables by their standard deviation ****;
*********************************************************;

egen sd_start2=sd(start2);
replace start2=start2/sd_start2;

egen sd_forworker=sd(forworker);
replace forworker=forworker/sd_forworker;

egen sd_mesoforshare=sd(mesoforshare);
replace mesoforshare=mesoforshare/sd_mesoforshare;

egen sd_indnonbraz=sd(indnonbraz);
replace indnonbraz=indnonbraz/sd_indnonbraz;

*****************************************;
**** Semi-parametric Selection Model ****;
**** Table 8 in the paper            ****;
*****************************************;

********************************;
**** Column (1)             ****;
**** Ease of Doing Business ****;
********************************;

**** Panel A : Column (1), Row (1);

* Selection equation;
probit indexp start2 , vce(cluster cnaemeso);

**** F-statistic Panel A : Column (1);

test start2;
predict findexp if e(sample), xb;
gen findexp2=findexp*findexp;
gen findexp3=findexp*findexp*findexp;

**** Panel B : Column (1), Row (1);

* Employment third-order polynomial;
reg lemploy indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel B : Column (1);

test findexp findexp2 findexp3;

**** Panel C : Column (1), Row (1);

* Wage third-order polynomial; 
reg felwageyr indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel C : Column (1);

test findexp findexp2 findexp3;
* Drop variables;
drop findexp findexp2 findexp3;

*****************************;
**** Column (2)          ****;
**** Firm foreign worker ****;
*****************************;

**** Panel A : Column (2), Row (1);

* Selection equation;
probit indexp forworker , vce(cluster cnaemeso);

**** F-statistic Panel A : Column (2);

test forworker;
predict findexp if e(sample), xb;
gen findexp2=findexp*findexp;
gen findexp3=findexp*findexp*findexp;

**** Panel B : Column (2), Row (1);

* Employment third-order polynomial;
reg lemploy indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel B : Column (2);

test findexp findexp2 findexp3;

**** Panel C : Column (2), Row (1);

* Wage third-order polynomial;
reg felwageyr indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel C : Column (2);

test findexp findexp2 findexp3;
* Drop variables;
drop findexp findexp2 findexp3;

*****************************;
**** Column (3)          ****;
**** Meso foreign worker ****;
*****************************;

**** Panel A : Column (3), Row (1);

* Selection equation;
probit indexp mesoforshare , vce(cluster cnaemeso);

**** F-statistic Panel A : Column (3);

test mesoforshare ;
predict findexp if e(sample), xb;
gen findexp2=findexp*findexp;
gen findexp3=findexp*findexp*findexp;

**** Panel B : Column (3), Row (1);

* Employment third-order polynomial;
reg lemploy indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel B : Column (3);

test findexp findexp2 findexp3;

**** Panel C : Column (3), Row (1);

* Wage third-order polynomial;
reg felwageyr indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel C : Column (3);

test findexp findexp2 findexp3;
* Drop variables;
drop findexp findexp2 findexp3;

*****************************************;
**** Column (4)                      ****;
**** Meso mass layoff foreign worker ****;
*****************************************;

**** Panel A : Column (4), Row (1);

* Selection equation;
probit indexp indnonbraz , vce(cluster cnaemeso);

**** F-statistic Panel A : Column (4);

test indnonbraz;
predict findexp if e(sample), xb;
gen findexp2=findexp*findexp;
gen findexp3=findexp*findexp*findexp;

**** Panel B : Column (4), Row (1);

* Employment third-order polynomial;
reg lemploy indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel B : Column (4);

test findexp findexp2 findexp3;

**** Panel C : Column (4), Row (1);

* Wage third-order polynomial;
reg felwageyr indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel C : Column (4);

test findexp findexp2 findexp3;
* Drop variables;
drop findexp findexp2 findexp3;

**************************************************************;
**** Column (5)                                           ****;
**** Ease of Business and Meso mass layoff foreign worker ****;
**************************************************************;

**** Panel A : Column (5), Row (1);

* Selection equation;
probit indexp start2 indnonbraz , vce(cluster cnaemeso);

**** F-statistic Panel A : Column (5);

test start2 indnonbraz;
predict findexp if e(sample), xb;
gen findexp2=findexp*findexp;
gen findexp3=findexp*findexp*findexp;

**** Panel B : Column (5), Row (1);

* Employment third-order polynomial;
reg lemploy indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel B : Column (5);

test findexp findexp2 findexp3;

**** Panel C : Column (5), Row (1);

* Wage third-order polynomial; 
reg felwageyr indexp findexp findexp2 findexp3 if year==1994, cluster(cnaemeso);

**** F-statistic Panel C : Column (5);

test findexp findexp2 findexp3;
* Drop variables;
drop findexp findexp2 findexp3;

******************************************;
**** Specification Assuming Normality ****;
******************************************;

*********************************************************************;
**** Results discussed in footnote 44 of the paper               ****;
**** Ease of doing business and Meso mass layoffs foreign worker ****;
*********************************************************************;

* Selection equation;
probit indexp start2 indnonbraz , vce(cluster cnaemeso);

* F-statistic selection equation;

test start2 indnonbraz;
predict findexp if e(sample), xb;
gen pdfindexp = normalden(findexp);
gen cdfindexp = normal(findexp);
gen imrindexp = pdfindexp/(1-cdfindexp) if indexp==1;
replace imrindexp = -pdfindexp/cdfindexp if indexp==0;

* Employment mills ratio;
reg lemploy indexp imrindexp if year==1994, cluster(cnaemeso);

* F-statistic employment mills ratio;

test imrindexp;

* Wage mills ratio; 
reg felwageyr indexp imrindexp if year==1994, cluster(cnaemeso);

* F-statistics mills ratio;

test imrindexp;

* Drop variables;
drop findexp imrindexp pdfindexp cdfindexp imrindexp;

log close;

