

#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global tables="/home/sjredding/himr-restud/stata/tables";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/condwtvfe/tanova/tanalysis-ack.log,replace;

*****************************************************;
**** Generate employment weights for sub-periods ****;
*****************************************************;

u $data/condwtvfe/mincer/agg-tmincer-all-fun.dta, clear;

gen num=1 if year==1986|year==1987|year==1988|year==1989;
replace num=2 if year==1990|year==1991|year==1992|year==1993;
replace num=3 if year==1994|year==1995|year==1996|year==1997|year==1998;

collapse (sum) employ , by(firm_subsibge num) fast;

ren employ employ_wght;
lab var employ_wght "firm_subsibge-num employment weights";

order firm_subsibge num;
so firm_subsibge num;
sa $data/condwtvfe/tanova/twithinbetween-ack-empweights.dta, replace;

********************************************;
**** Clean within-between decomposition ****;               
********************************************;

u $data/condwtvfe/tanova/twithinbetween-ack-1.dta;
gen num=1;
order firm_subsibge num;
so firm_subsibge num;
sa $data/condwtvfe/tanova/twithinbetween-ack-1-num.dta, replace;

u $data/condwtvfe/tanova/twithinbetween-ack-2.dta, clear;
gen num=2;
order firm_subsibge num;
so firm_subsibge num;
sa $data/condwtvfe/tanova/twithinbetween-ack-2-num.dta, replace;

u $data/condwtvfe/tanova/twithinbetween-ack-3.dta, clear;
gen num=3;
order firm_subsibge num;
so firm_subsibge num;
sa $data/condwtvfe/tanova/twithinbetween-ack-3-num.dta, replace;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;
*******************************************************************;

u $data/condwtvfe/tanova/twithinbetween-ack-1-num.dta, clear;
append using $data/condwtvfe/tanova/twithinbetween-ack-2-num.dta;
append using $data/condwtvfe/tanova/twithinbetween-ack-3-num.dta;

so firm_subsibge num;
merge 1:1 firm_subsibge num using $data/condwtvfe/tanova/twithinbetween-ack-empweights.dta;
tab _merge;

*******************************************************;
**** Implement decompositions by firm_subsibge-num ****;
*******************************************************;

gen test=ttot-(tobs+tres+tbetween+tworker+tcov_ffeobs+tcov_wfeobs+tcov_ffewfe);
bys num: su test, d;
drop test;

gen ntest=nttot-(ntobs+ntres+ntbetween+ntworker+ntcov_ffeobs+ntcov_wfeobs+ntcov_ffewfe);
bys num: su ntest, d;
drop ntest;

gen tsum=tobs+tres+tbetween+tworker+tcov_ffeobs+tcov_wfeobs+tcov_ffewfe;

gen s_tobs=tobs/tsum;
gen s_tres=tres/tsum;
gen s_tbetween=tbetween/tsum;
gen s_tworker=tworker/tsum;
gen s_tcov_ffeobs=tcov_ffeobs/tsum;
gen s_tcov_wfeobs=tcov_wfeobs/tsum;
gen s_tcov_ffewfe=tcov_ffewfe/tsum;

gen test=s_tobs+s_tres+s_tbetween+s_tworker+s_tcov_ffeobs+s_tcov_wfeobs+s_tcov_ffewfe;
su test, d;
drop test;

preserve;

***************************************************;
**** Table H 10 in Online Supplement           ****;
***** ACK Decomposition Across all Sub-periods ****;
***************************************************;

collapse (mean) s_tobs s_tres s_tbetween s_tworker s_tcov_ffeobs s_tcov_wfeobs s_tcov_ffewfe ///
[aw=employ_wght], fast;

outsheet s_tobs s_tres s_tbetween s_tworker s_tcov_ffeobs s_tcov_wfeobs s_tcov_ffewfe ///
using $tables/tanalysis-ack.csv, comma replace names;

restore;
preserve;

***********************************************************;
**** Table H 10 in Online Supplement                   ****;
***** ACK Decomposition for Each Sub-period Separately ****;
***********************************************************;

collapse (mean) s_tobs s_tres s_tbetween s_tworker s_tcov_ffeobs s_tcov_wfeobs s_tcov_ffewfe ///
[aw=employ_wght], by(num) fast;

outsheet s_tobs s_tres s_tbetween s_tworker s_tcov_ffeobs s_tcov_wfeobs s_tcov_ffewfe ///
using $tables/tanalysis-ack-num.csv, comma replace names;

restore;
