
#delimit;

clear;
clear matrix;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global personal="/home/sjredding/himr-restud/ado";

sysdir set PERSONAL $personal;

log using $logs/condwtvfe/tanova/tanova-ack.log,replace;

****************************************************;
* Estimate Abowd, Creecy and Kramarz Specification *;
****************************************************;

foreach num of numlist 1 2 3 {;

u $data/condwtvfe/tanova/rawdata-all.dta, clear;

su pis;
set seed 100;
bys pis: gen fob=1 if _n==1;
gen temp=runiform() if fob==1;
egen rnum=max(temp),by(pis);
drop temp;
lab var rnum "Random Variable Uniform(0,1)";
keep if rnum<0.01;
codebook pis;

if `num'==1 {;
keep if year==1986|year==1987|year==1988|year==1989;
local syear=1986;
local eyear=1989;
};
if `num'==2 {;
keep if year==1990|year==1991|year==1992|year==1993;
local syear=1990;
local eyear=1993;
};
if `num'==3 {;
keep if year==1994|year==1995|year==1996|year==1997|year==1998;
local syear=1994;
local eyear=1998;
};

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Age;
gen age=12 if indchild==1;
replace age=16 if indyouth==1;
replace age=20 if indadol==1;
replace age=27 if indnasc==1;
replace age=34 if indearly==1;
replace age=44 if indpeak==1;
replace age=57 if indlate==1;
replace age=65 if indretir==1;

su if age==.;

**************************;
* Baseline Specification *;
**************************;

egen firmid=group(firm_subsibge cnpj_radic);
egen industries=group(firm_subsibge);

* Abowd, Creecy and Kramarz regression;
*felsdvregdm lwageyr `demog' `educ' tenure2-tenure5 , ivar(pis) jvar(firmid) reff(industries) ///
*peff(wkrfe) feff(firmfe) xb(obslwageyr) res(reslwageyr) mover(wkrmult) mnum(firmmover) ///
*pobs(wkrobs) group(wkrgroup) feffse(firmfese);

felsdvreg lwageyr `demog' `educ' tenure2-tenure5 , ivar(pis) jvar(cnpj_radic) ///
peff(wkrfe) feff(firmfe) xb(obslwageyr) res(reslwageyr) mover(wkrmult) mnum(firmmover) ///
pobs(wkrobs) group(wkrgroup) feffse(firmfese) cons;

replace obslwageyr=obslwageyr+_b[_cons];

gen flwageyr=obslwageyr+wkrfe+firmfe;

lab var flwageyr        "Fitted worker log wage";
lab var reslwageyr 	"Worker residual log wage";
lab var obslwageyr 	"Worker observable component worker log wage";
lab var firmfe 	        "Firm fixed effect";
lab var wkrfe           "Worker fixed effect";

gen test=lwageyr-(obslwageyr+wkrfe+firmfe+reslwageyr);
su test, d;
drop test;

foreach var of varlist lwageyr flwageyr reslwageyr obslwageyr firmfe wkrfe {;
egen temp=mean(`var'),by(firm_subsibge);
gen n`var'=`var'-temp;
drop temp;
};

* Total, residual and model variance;

*residuals;
egen tres=sd(reslwageyr);
replace tres=tres*tres;

egen ntres=sd(nreslwageyr), by(firm_subsibge);
replace ntres=ntres*ntres;

*observed;
egen tobs=sd(obslwageyr);
replace tobs=tobs*tobs;

egen ntobs=sd(nobslwageyr), by(firm_subsibge);
replace ntobs=ntobs*ntobs;

*firm fixed effects (between component);
egen tbetween=sd(firmfe);
replace tbetween=tbetween*tbetween;

egen ntbetween=sd(nfirmfe), by(firm_subsibge);
replace ntbetween=ntbetween*ntbetween;

*worker fixed effects (between component);
egen tworker=sd(wkrfe);
replace tworker=tworker*tworker;

egen ntworker=sd(nwkrfe), by(firm_subsibge);
replace ntworker=ntworker*ntworker;

*2 times covariance of firm fixed effects and observed;
gen tcov_ffeobs=.;
correlate firmfe obslwageyr , covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace tcov_ffeobs = temp;
drop temp;

gen ntcov_ffeobs=.;
foreach ind of numlist 2(1)13 {;
correlate nfirmfe nobslwageyr if firm_subsibge==`ind', covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace ntcov_ffeobs = temp if firm_subsibge==`ind';
drop temp;
};

*2 times covariance of worker fixed effects and observed;
gen tcov_wfeobs=.;
correlate wkrfe obslwageyr , covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace tcov_wfeobs = temp;
drop temp;

gen ntcov_wfeobs=.;
foreach ind of numlist 2(1)13 {;
correlate nwkrfe nobslwageyr if firm_subsibge==`ind', covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace ntcov_wfeobs = temp if firm_subsibge==`ind';
drop temp;
};

*2 times covariance of firm and worker fixed effects;
gen tcov_ffewfe=.;
correlate firmfe wkrfe , covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace tcov_ffewfe = temp;
drop temp;

gen ntcov_ffewfe=.;
foreach ind of numlist 2(1)13 {;
correlate nfirmfe nwkrfe if firm_subsibge==`ind', covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace ntcov_ffewfe = temp if firm_subsibge==`ind';
drop temp;
};

*total;
egen ttot=sd(lwageyr);
replace ttot=ttot*ttot;

egen nttot=sd(nlwageyr), by(firm_subsibge);
replace nttot=nttot*nttot;

*************;
* Save Data *;
*************;

collapse (mean) ttot tobs tres tbetween tworker tcov_ffeobs tcov_wfeobs tcov_ffewfe  
nttot ntobs ntres ntbetween ntworker ntcov_ffeobs ntcov_wfeobs ntcov_ffewfe  
, by(firm_subsibge) fast;

lab var ttot "Total sum of squares of log wages";
lab var tobs "Worker observables component";
lab var tres "Residual component";
lab var tbetween "Firm fixed effects component";
lab var tworker  "Worker fixed effects component";
lab var tcov_ffeobs "Covariance firm fixed effects and worker observables component";
lab var tcov_wfeobs "Covariance worker fixed effects and worker observables component";
lab var tcov_ffewfe "Covariance firm fixed effects and worker fixed effects component";

lab var nttot "Total sum of squares of log wages by firm_subsibge";
lab var ntobs "Worker observables component by firm_subsibge";
lab var ntres "Residual component by firm_subsibge";
lab var ntbetween "Firm fixed effects component by firm_subsibge";
lab var ntworker  "Worker fixed effects component by firm_subsibge";
lab var ntcov_ffeobs "Covariance firm fixed effects and worker observables component by firm_subsibge";
lab var ntcov_wfeobs "Covariance worker fixed effects and worker observables component by firm_subsibge";
lab var ntcov_ffewfe "Covariance firm fixed effects and worker fixed effects component by firm_subsibge";

order firm_subsibge ttot tobs tres tbetween tworker tcov_ffeobs tcov_wfeobs tcov_ffewfe;
so firm_subsibge;
sa $data/condwtvfe/tanova/twithinbetween-ack-`num'.dta,replace;

};

log close;

