
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*********************************;
* Code for Analysis of Variance *;
*********************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/condwtvfe/tanova/tanova_firm-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

***************************;
**** Merge FUNCEX data ****;
***************************;

so cnpj_radic firm_subsibge pis;
merge cnpj_radic using $data/funcex/expimp-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;

drop firm_indexp;

*********************;
* Setup and Loop    *;
*********************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Loop;
gen tobs = .;
gen tcov=.;
gen tbetween=.;
gen tbetweenfirm=.;
gen tbetweenmeso=.;
gen tres = .;
gen tbetween_exp=.;
gen twithin_exp=.;
gen twithin_nonexp=.;
gen ttot = .;
foreach sec of numlist 2(1)13 {;
display "Industry is";
display `sec';

* Mincer regressions;
areg lwageyr `demog' `educ' tenure2-tenure5 if firm_subsibge==`sec', robust abs(cnpj_radic);
predict reslwageyr if e(sample), res;
predict obslwageyr if e(sample), xb;
predict felwageyr if e(sample), d;

* Total, residual and model variance;

*residuals;
egen temp=sd(reslwageyr), by(firm_subsibge);
replace temp=temp*temp;
replace tres=temp if  firm_subsibge==`sec';
drop temp;

*observed;
egen temp=sd(obslwageyr), by(firm_subsibge);
replace temp=temp*temp;
replace tobs = temp if firm_subsibge==`sec';
drop temp;

*fixed effects (between component);
egen temp=sd(felwageyr), by(firm_subsibge);
replace temp=temp*temp;
replace tbetween = temp if firm_subsibge==`sec';
drop temp;

*2 times covariance of fixed effects and observed;
correlate felwageyr obslwageyr, covariance;
gen temp = .;
replace temp =  r(cov_12);
replace temp = 2*temp;
replace tcov = temp if firm_subsibge==`sec';
drop temp;

*total;
egen temp=sd(lwageyr), by(firm_subsibge);
replace temp=temp*temp;
replace ttot = temp if firm_subsibge==`sec';
drop temp;

* within exporters, within nonexporters, and between exporters and nonexporters;
if `yr'>=1990 {;
areg felwageyr if firm_subsibge==`sec', abs(indexp);
predict ewithin if e(sample), res;
predict ebetween if e(sample), xbd;

egen temp = sd(ebetween), by(firm_subsibge);
replace temp = temp*temp;
replace tbetween_exp=temp if firm_subsibge==`sec';
drop temp;

egen temp = sd(ewithin), by(firm_subsibge indexp);
replace temp = temp*temp;
replace twithin_exp=temp if firm_subsibge==`sec'&indexp==1;
replace twithin_nonexp=temp if firm_subsibge==`sec'&indexp==0;
drop temp;

drop ewithin;
drop ebetween;
};

* Decompose firm effects into within and between regions;

areg felwageyr if firm_subsibge==`sec', robust abs(meso);
predict felwageyrmeso if e(sample), res;
predict mesolwageyr if e(sample), d;

egen temp=sd(felwageyrmeso), by(firm_subsibge);
replace temp=temp*temp;
replace tbetweenfirm = temp if firm_subsibge==`sec';
drop temp;

egen temp=sd(mesolwageyr), by(firm_subsibge);
replace temp=temp*temp;
replace tbetweenmeso = temp if firm_subsibge==`sec';
drop temp;

drop obslwageyr;
drop reslwageyr;
drop felwageyr;
drop felwageyrmeso;
drop mesolwageyr;

};

gen total = tobs + tbetween + tres + tcov;
gen n_nonexp = 0; // for adjustment of 1/N in variance; 
replace n_nonexp = 1 if (indexp == 0);
rename indexp n_exp;

*************;
* Save Data *;
*************;

collapse (mean) ttot tobs tres tcov tbetween tbetween_exp twithin_exp twithin_nonexp total tbetweenfirm tbetweenmeso 
(sum) n_exp n_nonexp, by(firm_subsibge) fast;

* Within group vairances are constructed as 1/N_group rather than 1/N, so adjust to fix;
gen n = n_exp + n_nonexp;
replace twithin_exp = twithin_exp * n_exp / n;
replace twithin_nonexp = twithin_nonexp * n_nonexp / n;
drop n n_nonexp n_exp;

lab var ttot "Total sum of squares of log wages";
lab var tobs "Worker observables component";
lab var tres "Residual component conditional on worker observables and tv fe";
lab var tcov "Twice the covariance of the between component and observables";
lab var tbetween "Between-firm component conditional on worker observables and tv fe";
lab var tbetween_exp "Between exporters component conditional on worker observables and tv fe";
lab var twithin_exp "Within exporters component conditional on worker observables and tv fe";
lab var twithin_nonexp "Within nonexporters component conditional on worker observables and tv fe";
lab var tbetweenfirm "Within-meso between firm component";
lab var tbetweenmeso "Between-meso between firm component";

gen year=`yr';

so firm_subsibge year;
order year firm_subsibge tobs tres tcov tbetween tbetween_exp twithin_exp twithin_nonexp ttot total;
sa $data/condwtvfe/tanova/twithinbetween-firm-`yr'.dta,replace;

log close;

};

********************************************;
* Merge Within-Between Dispersion Datasets *;
********************************************;

#delimit;
clear;
u $data/condwtvfe/tanova/twithinbetween-firm-1986.dta;
foreach yr of numlist 1987(1)1998 {;
append using $data/condwtvfe/tanova/twithinbetween-firm-`yr'.dta;
};
so firm_subsibge year;
sa $data/condwtvfe/tanova/twithinbetween-firm-all.dta, replace;



