
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*********************************************************************************;
**** Robustness test for wage inequality within sector-occupation-year cells ****;
**** excluding time-varying firm wage component                              ****;
*********************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*********************************;
* Code for Analysis of Variance *;
*********************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/condwtvfe/tanova/tanova-robust-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

*********************;
* Setup and Loop    *;
*********************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Loop;
gen tobs = .;
gen tres = .;
gen ttot = .;
foreach sec of numlist 2(1)13 {;
display "Industry is";
display `sec';
foreach occ of numlist 1(1)5 {;
display "Occupation is";
display `occ';

* Mincer regressions;
reg lwageyr `demog' `educ' tenure2-tenure5 if firm_subsibge==`sec'&occup==`occ', robust;
predict reslwageyr if e(sample), res;
predict obslwageyr if e(sample), xb;

* Total, residual and model variance;

*residuals;
egen temp=sd(reslwageyr), by(occup firm_subsibge);
replace temp=temp*temp;
replace tres=temp if  firm_subsibge==`sec'&occup==`occ';
drop temp;

*observed;
egen temp=sd(obslwageyr), by(occup firm_subsibge);
replace temp=temp*temp;
replace tobs = temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

*total;
egen temp=sd(lwageyr), by(occup firm_subsibge);
replace temp=temp*temp;
replace ttot = temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

drop obslwageyr;
drop reslwageyr;

};
};

gen total = tobs + tres;

*************;
* Save Data *;
*************;

collapse (mean) ttot tobs tres total , by(occup firm_subsibge) fast;

lab var ttot "Total sum of squares of log wages";
lab var tobs "Worker observables component";
lab var tres "Residual component conditional on worker observables and tv fe";

gen year=`yr';

so firm_subsibge occup year;
order year firm_subsibge occup tobs tres ttot total;
sa $data/condwtvfe/tanova/twithinbetween-robust-`yr'.dta,replace;

log close;

};

********************************************;
* Merge Within-Between Dispersion Datasets *;
********************************************;

#delimit;
clear;
u $data/condwtvfe/tanova/twithinbetween-robust-1986.dta;
foreach yr of numlist 1987(1)1998 {;
append using $data/condwtvfe/tanova/twithinbetween-robust-`yr'.dta;
};
so firm_subsibge occup year;
sa $data/condwtvfe/tanova/twithinbetween-robust-all.dta, replace;



