#delimit;

clear;
clear matrix;
set more off;
set scheme s1mono;

capture log close; 
log using $logs/csoanalysis-comcart.log, replace;


*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/pnad/sector-occupation-comcart/c-withinbetween-1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta;
};

lab var wgedisp     "overall wage dispersion";
lab var obsdisp     "wage dispersion explained by observables";

lab var swithin     "within sectors conditional log wage component";
lab var sbetween    "between sectors conditional log wage component";
lab var scond       "conditional log wage component (across sectors)";

lab var owithin     "within occupations conditional log wage component";
lab var obetween    "between occupations conditional log wage component";
lab var ocond       "conditional log wage component (across occupations)";

lab var sowithin    "within sector-occupations conditional log wage component";
lab var sobetween   "between sector-occupations conditional log wage component";
lab var socond      "conditional log wage component (across sector-occupations)";

lab var oowithin    "within detailed occupations log wage component";
lab var oobetween   "between detailed occupations log wage component";
lab var oocond      "total log wage component (across detailed occupations)";

lab var soowithin   "within sector-detailed-occupations log wage component";
lab var soobetween  "between sector-detailed-occupations log wage component";
lab var soocond     "total log wage component (across sector-detailed-occupations)";

local outvar="wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond";

order year wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond;
sort year;
sa $data/pnad/sector-occupation-comcart/c-withinbetween-all.dta, replace;
outsheet `outvar' using $data/pnad/sector-occupation-comcart/univ-c-sectoroccupation-all.csv , comma names replace; 

****************************;
**** Use Mincer results ****;
****************************;

* Outsheet coefficients data for Excel table;

local vbles="b_indchild b_indyouth b_indadol b_indnasc b_indearly b_indpeak b_indlate b_indretir b_indfem b_indhigh b_indscoll b_indgrad";
outsheet year `vbles' using $data/pnad/sector-occupation-comcart/cso-mincer-coeff-results-year.csv, comma replace names nolabel;
local sbles="se_indchild se_indyouth se_indadol se_indnasc se_indearly se_indpeak se_indlate se_indretir se_indfem se_indhigh se_indscoll se_indgrad regR2 regobs";
outsheet year `sbles' using $data/pnad/sector-occupation-comcart/cso-mincer-se-results-year.csv, comma replace names nolabel;

*************************************************;
**** Analyze Change in Return to Observables ****;
*************************************************;

clear;
u $data/pnad/sector-occupation-comcart/c-withinbetween-all.dta;

* Returns to Education;

gen b_prim=0;
keep year b_prim b_indhigh b_indscoll b_indgrad;
ren b_prim educ1;
ren b_indhigh educ2;
ren b_indscoll educ3;
ren b_indgrad educ4;

reshape long educ , i(year) j(elevel);

lab def elevel 1 "Primary" 2 "High" 3 "Some College" 4 "College";
lab val elevel elevel;

twoway (scatter educ elevel if year==1986 , c(l) msymbol(O) lpattern(solid) lcolor(black) lwidth(thick))
(scatter educ elevel if year==1995 , c(l) msymbol(Oh) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter educ elevel if year==1998 , c(l) msymbol(X) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16)) 
ytitle(Coeff. Log Wage Regression)
xtitle(Education Level)
xlabel(1 2 3 4, valuelabel)
legend(lab(1 "1986") lab(2 "1995") lab(3 "1998"))
title(Returns to Education Over Time)
;

graph bar educ if (year==1986|year==1990|year==1995|year==1998)&elevel==2 
, over(year) ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel A: High School) ytitle(Estimated Coefficient) saving($grphcc/sector-occupation/educ2,replace);
graph bar educ if (year==1986|year==1990|year==1995|year==1998)&elevel==3 
, over(year) ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel B: Some College) ytitle(Estimated Coefficient) saving($grphcc/sector-occupation/educ3,replace);
graph bar educ if (year==1986|year==1990|year==1995|year==1998)&elevel==4 
, over(year)  ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel C: College Graduate) ytitle(Estimated Coefficient) saving($grphcc/sector-occupation/educ4,replace);

**** Figure A1 for appendix;

gr combine "$grph/sector-occupation/educ2.gph"
"$grph/sector-occupation/educ3.gph"
"$grph/sector-occupation/educ4.gph"
,
iscale(0.5)
saving($grphcc/sector-occupation/educreturns,replace)
; 
* title(Figure A1: Returns to Education Over time);

graph export $grph/sector-occupation/educreturns.eps, as(eps) replace;

**** Figure A2 for appendix;

* Returns to Age;

u $data/pnad/sector-occupation-comcart/c-withinbetween-all.dta, clear;

keep year b_indchild b_indyouth b_indadol b_indnasc b_indearly b_indpeak b_indlate b_indretir;

ren b_indchild age1;
ren b_indyouth age2; 
ren b_indadol age3; 
ren b_indnasc age4;
ren b_indearly age5; 
ren b_indpeak age6; 
ren b_indlate age7;
ren b_indretir age8;

gen base=age1;
replace age1=age1-base;
replace age2=age2-base;
replace age3=age3-base;
replace age4=age4-base;
replace age5=age5-base;
replace age6=age6-base;
replace age7=age7-base;
replace age8=age8-base;

reshape long age , i(year) j(alevel);

lab def alevel 1 "10-14" 2 "15-17" 3 "18-24" 4 "25-29" 5 "30-39" 6 "40-49" 7 "50-64" 8 "> 65";
lab val alevel alevel;

twoway (scatter age alevel if year==1986 , c(l) msymbol(O) lpattern(solid) lcolor(black) lwidth(thick))
(scatter age alevel if year==1995 , c(l) msymbol(Oh) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter age alevel if year==1998 , c(l) msymbol(X) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16)) 
ytitle(Coeff. Log Wage Regression)
xtitle(Age)
xlabel(1 2 3 4 5 6 7 8, valuelabel)
legend(lab(1 "1986") lab(2 "1995") lab(3 "1998"))
title(Returns to Age Over Time)
saving($grphcc/sector-occupation/agereturns,replace)
;

*************************;
**** Analyze Results ****;
*************************;

u $data/pnad/sector-occupation-comcart/c-withinbetween-all.dta, clear;

gen stest=swithin+sbetween;
replace stest=stest-scond;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ocond;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-socond;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'95;
};   

gen data=1;

*************************************************;
**** Observables Inequality Tables for Paper ****;
*************************************************;

gen ash_sobs=obsdisp/wgedisp;
gen ash_swth=scond/wgedisp;

* Observables contribution in each year;
list year ash_sobs ash_swth;

foreach var of varlist ash_sobs ash_swth {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist wgedisp obsdisp scond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'95=(`var'98-`var'95)/`var'95; 
};

gen cnt_sobs86=(ash_sobs86*d_obsdisp86)/d_wgedisp86;
gen cnt_swth86=(ash_swth86*d_scond86)/d_wgedisp86;

* Level within contributions in 1990;

format ash_sobs ash_swth %10.4f;
table data if year==1990, c(mean ash_sobs mean ash_swth);

* Level within contributions in 1995;

format ash_sobs ash_swth %10.4f;
table data if year==1995, c(mean ash_sobs mean ash_swth);

* Observables contributions 1986-1995;

format d_wgedisp86 cnt_sobs86 ash_sobs86 d_obsdisp86 %10.4f;
table data if year==1995, c(mean d_wgedisp86 mean cnt_sobs86 mean ash_sobs86 mean d_obsdisp86);

* Within-group contributions 1986-1995;

format d_wgedisp86 cnt_swth86 ash_swth86 d_scond86 %10.4f;
table data if year==1995, c(mean d_wgedisp86 mean cnt_swth86 mean ash_swth86 mean d_scond86);

**************************************************;
**** Within-Group Inequality Tables for Paper ****;
**************************************************;


gen sh_swithin=swithin/scond;
gen sh_owithin=owithin/ocond;
gen sh_sowithin=sowithin/socond;
gen sh_oowithin=oowithin/oocond;
gen sh_soowithin=soowithin/soocond;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'95=(`var'98-`var'95)/`var'95; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_scond86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ocond86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_socond86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oocond86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soocond86;

gen cnt_swithin95=(sh_swithin95*d_swithin95)/d_scond95;
gen cnt_owithin95=(sh_owithin95*d_owithin95)/d_ocond95;
gen cnt_sowithin95=(sh_sowithin95*d_sowithin95)/d_socond95;
gen cnt_oowithin95=(sh_oowithin95*d_oowithin95)/d_oocond95;
gen cnt_soowithin95=(sh_soowithin95*d_soowithin95)/d_soocond95;

* Level within contributions in 1990;

format sh_swithin sh_owithin sh_sowithin %10.3f;
table data if year==1990, c(mean sh_swithin mean sh_owithin mean sh_sowithin);

* Sector contributions 1986-1995;

format d_scond86 cnt_swithin86 sh_swithin86 d_swithin86 d_sbetween86 %10.3f;
table data if year==1995, c(mean d_scond86 mean cnt_swithin86 mean sh_swithin86 mean d_swithin86 mean d_sbetween86);

* Occupation contributions 1986-1995;

format d_ocond86 cnt_owithin86 sh_owithin86 d_owithin86 d_obetween86 %10.3f;
table data if year==1995, c(mean d_ocond86 mean cnt_owithin86 mean sh_owithin86 mean d_owithin86 mean d_obetween86);

* Sector-occupation contributions 1986-1995;

format d_socond86 cnt_sowithin86 sh_sowithin86 d_sowithin86 d_sobetween86 %10.3f;
table data if year==1995, c(mean d_socond86 mean cnt_sowithin86 mean sh_sowithin86 mean d_sowithin86 mean d_sobetween86);

**********************************************************;
**** Robustness Tables 1986-1995 for Paper            ****;
**** More Detailed Occupations and Sector-Occupations ****;
**********************************************************;

* Level within contributions in 1990;

format sh_oowithin sh_soowithin %10.3f;
table data if year==1990, c(mean sh_oowithin mean sh_soowithin);

* Detailed Occupation contributions 1986-1995;

format d_oocond86 cnt_oowithin86 sh_oowithin86 d_oowithin86 d_oobetween86 %10.3f;
table data if year==1995, c(mean d_oocond86 mean cnt_oowithin86 mean sh_oowithin86 mean d_oowithin86 mean d_oobetween86);

* Sector-Detailed-Occupation contributions 1986-1995;

format d_soocond86 cnt_soowithin86 sh_soowithin86 d_soowithin86 d_soobetween86 %10.3f;
table data if year==1995, c(mean d_soocond86 mean cnt_soowithin86 mean sh_soowithin86 mean d_soowithin86 mean d_soobetween86);

***********************************************;
**** Robustness Tables 1995-1998 for Paper ****;
**** More Detailed Occupations and Sectors ****;
***********************************************;

* Level within contributions in 1995;

format sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin %10.3f;
table data if year==1995, c(mean sh_swithin mean sh_owithin mean sh_sowithin mean sh_oowithin mean sh_soowithin);

* Sector contributions 1995-1998;

format d_scond95 cnt_swithin95 sh_swithin95 d_swithin95 d_sbetween95 %10.3f;
table data if year==1995, c(mean d_scond95 mean cnt_swithin95 mean sh_swithin95 mean d_swithin95 mean d_sbetween95);

* Occupation contributions 1995-1998;

format d_ocond95 cnt_owithin95 sh_owithin95 d_owithin95 d_obetween95 %10.3f;
table data if year==1995, c(mean d_ocond95 mean cnt_owithin95 mean sh_owithin95 mean d_owithin95 mean d_obetween95);

* Sector-occupation contributions 1995-1998;

format d_socond95 cnt_sowithin95 sh_sowithin95 d_sowithin95 d_sobetween95 %10.3f;
table data if year==1995, c(mean d_socond95 mean cnt_sowithin95 mean sh_sowithin95 mean d_sowithin95 mean d_sobetween95);

* Detailed Occupation contributions 1995-1998;

format d_oocond95 cnt_oowithin95 sh_oowithin95 d_oowithin95 d_oobetween95 %10.3f;
table data if year==1995, c(mean d_oocond95 mean cnt_oowithin95 mean sh_oowithin95 mean d_oowithin95 mean d_oobetween95);

* Sector-Detailed-Occupation contributions 1995-1998;

format d_soocond95 cnt_soowithin95 sh_soowithin95 d_soowithin95 d_soobetween95 %10.3f;
table data if year==1995, c(mean d_soocond95 mean cnt_soowithin95 mean sh_soowithin95 mean d_soowithin95 mean d_soobetween95);

*************************************;
**** Overall Index Decomposition ****;
*************************************;

twoway 
(scatter iwgedisp year, msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iobsdisp year, msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Sector") lab(4 "Between Sector"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Log Wage Dispersion Decomposition (Sectors)", size(medlarge))
saving($grphcc/sector-occupation/c-i-sector,replace)
;

twoway (scatter iwgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iobsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Occupation") lab(4 "Between Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Log Wage Dispersion Decomposition (Occupations)", size(medlarge))
saving($grphcc/sector-occupation/c-i-occupation,replace)
;

twoway (scatter iwgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick)) 
(scatter iobsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Sector-Occupation") lab(4 "Between Sector-Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Log Wage Dispersion Decomposition (Sector-Occupations)", size(medlarge))
saving($grphcc/sector-occupation/c-i-sectoroccupation,replace)
;

*****************************************;
**** Conditional Index Decomposition ****;
*****************************************;

* Observables and within-group;

twoway(scatter iwgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iobsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(orange) lwidth(medium))
(scatter iscond year , msymbol(i) c(l) lpattern(dash) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Residual"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Panel A: Observables and Residual Inequality", size(medlarge))
saving($grphcc/sector-occupation/c-i-rawobs,replace)
;

graph export $grph/sector-occupation/c-i-rawobs.eps, as(eps) replace;

* Within-group sectors;

twoway 
(scatter iscond year, msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Sector") lab(3 "Between Sector"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0))
title("Within-Group Wage Inequality Decomposition (Sectors)", size(medlarge))
saving($grphcc/sector-occupation/c-i-sector-alt,replace)
;

* Within-group occupations;

twoway (scatter iocond year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Occupation") lab(3 "Between Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0))
title("Within-Group Wage Inequality Decomposition (Occupations)", size(medlarge))
saving($grphcc/sector-occupation/c-i-occupation-alt,replace)
;

* Within-group sector-occupations;

twoway 
(scatter isocond year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Residual") lab(2 "Within Sector-Occupation") lab(3 "Between Sector-Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.10 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Panel B: Residual Inequality", size(medlarge))
saving($grphcc/sector-occupation/c-i-sectoroccupation-alt,replace)
;

graph export $grph/sector-occupation/c-i-sectoroccupation-alt.eps, as(eps) replace;

**** New way of combining the figures January 2012;

gr combine "$grph/sector-occupation/c-i-rawobs.gph"
"$grph/sector-occupation/c-i-sectoroccupation-alt.gph"
,
graphregion(fcolor(gs16))
iscale(0.4)
note(Note: Each series expressed as a difference from its 1986 value.)
saving($grphcc/sector-occupation/total-obs-within-all,replace)
;

graph export $grph/sector-occupation/total-obs-within-all.eps, as(eps) replace;

***************************************************;
**** Conditional Index Decomposition for Paper ****;
***************************************************;

* Observables and within-group;

twoway(scatter iwgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iobsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter iscond year , msymbol(i) c(l) lpattern(dash) lcolor(black) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within-Group"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0), margin(small))
note(Note: Each series expressed as a difference from its 1986 value.)
saving($grphcc/sector-occupation/c-i-rawobs-bw,replace)
;

* Within-group sectors;

twoway 
(scatter iscond year, msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(dash) lcolor(black) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Sector") lab(3 "Between Sector"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0), margin(small))
title(Panel A: Sectors)
saving($grphcc/sector-occupation/c-i-sector-alt-bw,replace)
;

* Within-group occupations;

twoway (scatter iocond year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(dash) lcolor(black) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Occupation") lab(3 "Between Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0), margin(small))
title(Panel B: Occupations)
saving($grphcc/sector-occupation/c-i-occupation-alt-bw,replace)
;

* Within-group sector-occupations;

twoway 
(scatter isocond year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(dash) lcolor(black) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Sector-Occupation") lab(3 "Between Sector-Occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0))
title("Panel C: Sector-Occupations")
saving($grphcc/sector-occupation/c-i-sectoroccupation-alt-bw,replace)
;

gr combine "$grph/sector-occupation/c-i-sector-alt-bw.gph"
"$grph/sector-occupation/c-i-occupation-alt-bw.gph"
"$grph/sector-occupation/c-i-sectoroccupation-alt-bw.gph"
,
graphregion(fcolor(gs16))
iscale(0.4)
note(Note: Each series expressed as a difference from its 1986 value.)
saving($grphcc/sector-occupation/within-group-so-all-bw,replace)
;

*************************************;
**** Overall Level Decomposition ****;
*************************************;

twoway 
(scatter wgedisp year, msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter obsdisp year, msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter swithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter sbetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Sector") lab(4 "Between Sector"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Variance Log Wage)
title("Log Wage Dispersion Decomposition (Sectors)", size(medlarge))
saving($grphcc/sector-occupation/c-sector,replace)
;

twoway (scatter wgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter obsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter owithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter obetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Occupation") lab(4 "Between Occupation"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Variance Log Wage)
title("Log Wage Dispersion Decomposition (Occupations)", size(medlarge))
saving($grphcc/sector-occupation/c-occupation,replace)
;

twoway (scatter wgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick)) 
(scatter obsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter sowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter sobetween year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Within Sector-Occupation") lab(4 "Between Sector-Occupation"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Variance Log Wage)
title("Log Wage Dispersion Decomposition (Sector-Occupations)", size(medlarge))
saving($grphcc/sector-occupation/c-sectoroccupation,replace)
;

log close;
