
************************************************************************;
**** This file generates employment weights for summarising results ****;
************************************************************************;

#delimit;

clear all;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

******************************************************;
**** Merge employment by industry-occupation-year ****;
******************************************************;

clear;
u $data/prepdata/emp-ind-occup-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/emp-ind-occup-`yr'.dta;
};
so year;
sa $data/prepdata/emp-ind-occup-all.dta, replace;

**********************************************************;
**** Collapse to get total employment in each year,   ****;
**** generate aggregate weights, and merge them in    ****;
**********************************************************;

collapse (sum) employ, by(year) fast;
ren employ tot_employ;
so year;
merge year using $data/prepdata/emp-ind-occup-all.dta;
drop _m;
//weight on industry-occupation is its share of total employment
gen weight = employ / tot_employ;
so occup year;
sa $data/prepdata/emp-ind-occup-all-wweights.dta, replace;

**********************************************************************;
**** Collapse to get total employment by occupation in each year, ****;
**** generate occupation weights, and merge them in               ****;
**********************************************************************;

u $data/prepdata/emp-ind-occup-all.dta, clear;
collapse (sum) employ, by(year occup) fast;
ren employ employ_occup;
so occup year;
merge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
drop _m;
//weight on occupation is its share of occup employment
gen weight_occup = employ / employ_occup;
so firm_subsibge year;
sa $data/prepdata/emp-ind-occup-all-wweights.dta, replace;

**********************************************************************;
**** Collapse to get total employment by industry in each year,   ****;
**** generate industry weights, and merge them in                 ****;
**********************************************************************;

u $data/prepdata/emp-ind-occup-all.dta, clear;
collapse (sum) employ, by(year firm_subsibge) fast;
ren employ employ_industry;
so firm_subsibge year;
merge firm_subsibge year using $data/prepdata/emp-ind-occup-all-wweights.dta;
drop _m;
//weight on industry is its share of industry employment
gen weight_industry = employ / employ_industry;
so firm_subsibge occup year;
sa $data/prepdata/emp-ind-occup-all-wweights.dta, replace;

****************************************************;
**** Create industry level dataset with weights ****;
****************************************************;

u $data/prepdata/emp-ind-occup-all.dta, clear;
collapse (sum) employ, by(year) fast;
ren employ tot_employ;
so year;
merge year using $data/prepdata/emp-ind-occup-all.dta;
drop _m;
//weight on industry-occupation is its share of total employment
collapse (mean) tot_employ (sum) employ, by(firm_subsibge year) fast; 
gen weight = employ / tot_employ;
keep firm_subsibge year weight;
so firm_subsibge year;
sa $data/prepdata/emp-ind-all-wweights.dta, replace;
