
#delimit;

***************************************************************************;
**** Constructs a robustness sample including manufacturing and mining ****;
***************************************************************************;

display "Starting sample";
su pis;

display "keep if firm_subsibge>=1&firm_subsibge<=13";
keep if firm_subsibge>=1&firm_subsibge<=13;
su pis;

* Drop observations with missing firm_subsibge code;
display "Drop missing firm_subsibge code";
display "drop if firm_subsibge==.";
drop if firm_subsibge==.;
su pis;

* DEFINE SAMPLE;

display "Drop missing wage information";
display "drop if wageyr<=0";
display "drop if wageyr==.";
drop if wageyr<=0;
drop if wageyr==.;
su pis;

* Keep highest wage for each worker if more than one wage;
display "Keep highest wage for each worker if more than one wage";
gsort pis -wageyr;
quietly by pis: gen order=_n;
tab order;
drop if order>1;
drop order;
gen worker=_n;
su pis;

* Define variables;

gen lwageyr=ln(wageyr);
gen employ=1;

* Define occupations;

gen occup=.;
replace occup=1 if indprof==1;
replace occup=2 if indtech==1;
replace occup=3 if indwhit==1;
replace occup=4 if indsklb==1;
replace occup=5 if indunsklb==1;

display "Drop if occupation missing";
drop if occup==.;
su pis;

* Drop based on observables in Mincer regression;

display "Drop based on worker observables";
drop if indchild==.;
drop if indyouth==.;
drop if indadol==.;
drop if indnasc==.;
drop if indearly==.;
drop if indpeak==.;
drop if indlate==.;
drop if indretir==.;
drop if indfem==.;

drop if indhigh==.;
drop if indscoll==.;
drop if indgrad==.;

drop if indprof==.;
drop if indtech==.;
drop if indwhit==.;
drop if indsklb==.;
drop if indunsklb==.;

drop if temp_empr==.;
su pis;

* Drop data for small firms with less than five employees;
display "Drop data for small firms with less than five employees";
egen firm_emp=count(employ), by(cnpj_radic);
drop if firm_emp<5;
su pis;

so cnpj_radic pis;
