
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*******************************************************************;
**** This file undertakes the regional robustness              ****;
**** for the decomposition of residual wage inequality         ****;
**** into within and between sector-occupation components      ****;
**** in Table H2 of the online supplement (Columns (3) and (4) ****; 
**** for Sao Paulo only                                        ****;
*******************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/c-sao-withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/c-sao-withinbetween-`yr'.dta;
};

lab var wgedisp 	"overall wage dispersion";
lab var obsdisp 	"wage dispersion explained by observables";

lab var swithin 	"within sectors conditional log wage component";
lab var sbetween 	"between sectors conditional log wage component";
lab var scond 		"conditional log wage component (across sectors)";

lab var owithin 	"within occupations conditional log wage component";
lab var obetween 	"between occupations conditional log wage component";
lab var ocond 		"conditional log wage component (across occupations)";

lab var sowithin 	"within sector-occupations conditional log wage component";
lab var sobetween 	"between sector-occupations conditional log wage component";
lab var socond 		"conditional log wage component (across sector-occupations)";

lab var oowithin 	"within detailed occupations log wage component";
lab var oobetween 	"between detailed occupations log wage component";
lab var oocond	 	"total log wage component (across detailed occupations)";

lab var soowithin 	"within sector-detailed-occupations log wage component";
lab var soobetween 	"between sector-detailed-occupations log wage component";
lab var soocond 	"total log wage component (across sector-detailed-occupations)";

local outvar="wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond";

order year wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond;
sort year;
sa $data/sector-occupation/c-sao-withinbetween-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-scond;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ocond;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-socond;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

gen data=1;

*************************************************;
**** Observables Inequality Tables for Paper ****;
*************************************************;

gen ash_sobs=obsdisp/wgedisp;
gen ash_swth=scond/wgedisp;

foreach var of varlist ash_sobs ash_swth {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist wgedisp obsdisp scond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_sobs86=(ash_sobs86*d_obsdisp86)/d_wgedisp86;
gen cnt_swth86=(ash_swth86*d_scond86)/d_wgedisp86;

**************************************************;
**** Within-Group Inequality Tables for Paper ****;
**************************************************;

gen sh_swithin=swithin/scond;
gen sh_owithin=owithin/ocond;
gen sh_sowithin=sowithin/socond;
gen sh_oowithin=oowithin/oocond;
gen sh_soowithin=soowithin/soocond;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_scond86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ocond86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_socond86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oocond86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soocond86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_scond94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ocond94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_socond94;
gen cnt_oowithin94=(sh_oowithin94*d_oowithin94)/d_oocond94;
gen cnt_soowithin94=(sh_soowithin94*d_soowithin94)/d_soocond94;

**** Decomposition of level of residual wage inequality 1994;
**** for Sao Paulo into within and between sector-occupation components;

**** Table H2, Column (3), Row (2);

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Decomposition of changes in residual wage inequality 1986-95;
**** for Sao Paulo into within and between sector-occupation components;

**** Table H2, Column (4), Row (2);

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

