
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*********************************************************************;
**** This file undertakes the regional robustness test           ****;
**** for the decomposition of residual wage inequality           ****;
**** into within and between sector-occupation-region components ****;
**** in Table H2 of the online supplement (Columns (3) and (4))  ****; 
*********************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/csoanalysis_sor.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/c-sor-withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/c-sor-withinbetween-`yr'.dta;
};

lab var wgedisp 	"overall wage dispersion";
lab var obsdisp 	"wage dispersion explained by observables";

lab var swithin 	"within sectors conditional log wage component";
lab var sbetween 	"between sectors conditional log wage component";
lab var scond 		"conditional log wage component (across sectors)";

lab var owithin 	"within occupations conditional log wage component";
lab var obetween 	"between occupations conditional log wage component";
lab var ocond 		"conditional log wage component (across occupations)";

lab var sowithin 	"within sector-occupations conditional log wage component";
lab var sobetween 	"between sector-occupations conditional log wage component";
lab var socond 		"conditional log wage component (across sector-occupations)";

lab var sorwithin 	"within sector-occupation-state log wage component";
lab var sorbetween 	"between sector-occupation-state log wage component";
lab var sorcond	 	"total log wage component (sector-occupation-state)";

lab var somwithin 	"within sector-occupation-meso log wage component";
lab var sombetween 	"between sector-occupation-meso log wage component";
lab var somcond 	"total log wage component (sector-occupation-meso)";

local outvar="wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond";

order year wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond;
sort year;
sa $data/sector-occupation/c-sor-withinbetween-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

u $data/sector-occupation/c-sor-withinbetween-all.dta, clear;

gen stest=swithin+sbetween;
replace stest=stest-scond;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ocond;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-socond;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond sorwithin sorbetween sorcond somwithin sombetween somcond {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

gen data=1;

*************************************************;
**** Observables Inequality Tables for Paper ****;
*************************************************;

gen ash_sobs=obsdisp/wgedisp;
gen ash_swth=scond/wgedisp;

foreach var of varlist ash_sobs ash_swth {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist wgedisp obsdisp scond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_sobs86=(ash_sobs86*d_obsdisp86)/d_wgedisp86;
gen cnt_swth86=(ash_swth86*d_scond86)/d_wgedisp86;

**************************************************;
**** Within-Group Inequality Tables for Paper ****;
**************************************************;

gen sh_swithin=swithin/scond;
gen sh_owithin=owithin/ocond;
gen sh_sowithin=sowithin/socond;
gen sh_sorwithin=sorwithin/sorcond;
gen sh_somwithin=somwithin/somcond;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_sorwithin sh_somwithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween owithin obetween ocond sowithin sobetween socond sorwithin sorbetween sorcond somwithin sombetween somcond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_scond86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ocond86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_socond86;
gen cnt_sorwithin86=(sh_sorwithin86*d_sorwithin86)/d_sorcond86;
gen cnt_somwithin86=(sh_somwithin86*d_somwithin86)/d_somcond86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_scond94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ocond94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_socond94;
gen cnt_sorwithin94=(sh_sorwithin94*d_sorwithin94)/d_sorcond94;
gen cnt_somwithin94=(sh_somwithin94*d_somwithin94)/d_somcond94;

**** Decomposition of level of residual wage inequality 1994;
**** within and between sector-occupation components;

**** Table H2, Column (3), Row (1);

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Decomposition of changes in residual wage inequality 1986-95;
**** into within and between sector-occupation components;

**** Table H2, Column (4), Row (1);

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

**********************************************************;
**** Robustness Tables 1986-1995 for Paper            ****;
**********************************************************;

**** Decomposition of level of residual wage inequality 1994;
**** within and between sector-occupation-state components;

**** Table H2, Column (3), Row (3);

format sh_sorwithin %10.3f;
table data if year==1994, c(mean sh_sorwithin);

**** Decomposition of level of residual wage inequality 1994;
**** within and between sector-occupation-meso components;

**** Table H2, Column (3), Row (4);

format sh_somwithin %10.3f;
table data if year==1994, c(mean sh_somwithin);

**** Decomposition of changes in residual wage inequality 1994;
**** within and between sector-occupation-state components;

**** Table H2, Column (4), Row (3);

format cnt_sorwithin86 %10.3f;
table data if year==1995, c(mean cnt_sorwithin86);

**** Decomposition of changes in residual wage inequality 1994;
**** within and between sector-occupation-meso components;

**** Table H2, Column (4), Row (4);

format cnt_somwithin86 %10.3f;
table data if year==1995, c(mean cnt_somwithin86);

log close;
