
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global graphs="/home/sjredding/himr-restud/stata/graphs";

***************************************************************************************;
**** This file undertakes the decompositions of overall wage inequality            ****;
**** into within and between sector-occupation components for Table 1 in the paper ****;                                       ****;
***************************************************************************************;

log using $logs/sector-occupation/soanalysis.log,replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/withinbetween-`yr'.dta;
};

lab var swithin 	"within sectors log wage component";
lab var sbetween 	"between sectors log wage component";
lab var stotal 		"total log wage component (across sectors)";

lab var owithin 	"within occupations log wage component";
lab var obetween 	"between occupations log wage component";
lab var ototal 		"total log wage component (across occupations)";

lab var sowithin 	"within sector-occupations log wage component";
lab var sobetween 	"between sector-occupations log wage component";
lab var sototal 	"total log wage component (across sector-occupations)";

lab var oowithin 	"within detailed occupations log wage component";
lab var oobetween 	"between detailed occupations log wage component";
lab var oototal 	"total log wage component (across detailed occupations)";

lab var soowithin 	"within sector-detailed-occupations log wage component";
lab var soobetween 	"between sector-detailed-occupations log wage component";
lab var soototal 	"total log wage component (across sector-detailed-occupations)";

lab var lwageyr9050	"Ratio 90:50 percentiles of log wages";
lab var lwageyr5010	"Ratio 50:10 percentiles of log wages";

lab var fswithin9050	"Ratio 90:50 percentiles of sector within component";
lab var fswithin5010	"Ratio 50:10 percentiles of sector within component";
lab var fsbetween9050	"Ratio 90:50 percentiles of sector between component";
lab var fsbetween5010	"Ratio 50:10 percentiles of sector between component";

lab var fowithin9050	"Ratio 90:50 percentiles of occupation within component";
lab var fowithin5010	"Ratio 50:10 percentiles of occupation within component";
lab var fobetween9050	"Ratio 90:50 percentiles of occupation between component";
lab var fobetween5010	"Ratio 50:10 percentiles of occupation between component";

lab var fsowithin9050	"Ratio 90:50 percentiles of sector-occupation within component";
lab var fsowithin5010	"Ratio 50:10 percentiles of sector-occupation within component";
lab var fsobetween9050	"Ratio 90:50 percentiles of sector-occupation between component";
lab var fsobetween5010	"Ratio 50:10 percentiles of sector-occupation between component";

local outvar="year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal;
sort year;
sa $data/sector-occupation/withinbetween-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

gen sdtotal=(stotal^0.5);

local vars1="swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";
local vars2="oowithin oobetween oototal soowithin soobetween soototal";
local vars3="lwageyr9050 lwageyr5010";

foreach var of varlist `vars1' `vars2' `vars3' sdtotal {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

***********************************;
**** Baseline Tables for Paper ****;
***********************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;
gen sh_oowithin=oowithin/oototal;
gen sh_soowithin=soowithin/soototal;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal oowithin oobetween oototal soowithin soobetween soototal sdtotal {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

* Increase in variance and standard deviation of wages 1986-1995;

su d_stotal86 d_sdtotal86;

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_stotal86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ototal86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_sototal86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oototal86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soototal86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_stotal94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ototal94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_sototal94;
gen cnt_oowithin94=(sh_oowithin94*d_oowithin94)/d_oototal94;
gen cnt_soowithin94=(sh_soowithin94*d_soowithin94)/d_soototal94;

*******************************************************;
**** Generates the Results in Table 1 in the Paper ****;
*******************************************************;

**** Table 1 : Column (1), row (1), within component level, occupation 1994;

format sh_owithin %10.3f;
table data if year==1994, c(mean sh_owithin);

**** Table 1 : Column (1), row (2), within component level, sector 1994;

format sh_swithin %10.3f;
table data if year==1994, c(mean sh_swithin);

**** Table 1 : Column (1), row (3), within component level, sector-occupation 1994;

format sh_sowithin;
table data if year==1994, c(mean sh_sowithin);

**** Table 1 : Column (1), row (4), within component level, detailed occupation 1994;

format sh_oowithin %10.3f;
table data if year==1994, c(mean sh_oowithin);

**** Table 1 : Column (1), row (5), within component level, sector-detailed occupation 1994;

format sh_soowithin %10.3f;
table data if year==1994, c(mean sh_soowithin);

**** Table 1 : Column (2), row (1), within component changes, occupation 1986-95;

format cnt_owithin86 %10.3f;
table data if year==1995, c(mean cnt_owithin86);

**** Table 1 : Column (2), row (2), within component changes, sector 1986-95;

format cnt_swithin86 %10.3f;
table data if year==1995, c(mean cnt_swithin86);

**** Table 1 : Column (2), row (3), within component changes, sector-occupation 1986-95;

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

**** Table 1 : Column (2), row (4), within component changes, detailed occupation 1986-95;

format cnt_oowithin86 %10.3f;
table data if year==1995, c(mean cnt_oowithin86);

**** Table 1 : Column (2), row (5), within component changes, sector-detailed-occupation 1986-95;

format cnt_soowithin86 %10.3f;
table data if year==1995, c(mean cnt_soowithin86);

******************************************************;
**** Generates Figure H3 in the Online Supplement ****;
******************************************************;

#delimit;

twoway (scatter istotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector") lab(3 "Between sector"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel A: Sectors")
saving("$graphs/sector-occupation/sector.gph",replace);

twoway (scatter iototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within occupation") lab(3 "Between occupation"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel B: Occupations")
saving("$graphs/sector-occupation/occupation.gph",replace);

twoway (scatter isototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector-occupation") lab(3 "Between sector-occupation"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel C: Sector-occupations")
saving("$graphs/sector-occupation/sectoroccupation.gph",replace);

graph combine "$graphs/sector-occupation/sector.gph"
"$graphs/sector-occupation/occupation.gph"
"$graphs/sector-occupation/sectoroccupation.gph"
 ,
graphregion(fcolor(gs16))
iscale(0.4)

saving("$graphs/sector-occupation/so_index.gph",replace)
;

graph export "$graphs/sector-occupation/so_index.eps", as(eps) replace;

log close;
