
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*************************************************************************;
**** Robustness test decomposing overall wage inequality into within ****;
**** and between sector-occupation components including              ****;
**** agriculture and mining industries                               ****;
*************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/soanalysis_agmining.log,replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/withinbetween-agmining-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/withinbetween-agmining-`yr'.dta;
};

lab var swithin 	"within sectors log wage component";
lab var sbetween 	"between sectors log wage component";
lab var stotal 		"total log wage component (across sectors)";

lab var owithin 	"within occupations log wage component";
lab var obetween 	"between occupations log wage component";
lab var ototal 		"total log wage component (across occupations)";

lab var sowithin 	"within sector-occupations log wage component";
lab var sobetween 	"between sector-occupations log wage component";
lab var sototal 	"total log wage component (across sector-occupations)";

lab var oowithin 	"within detailed occupations log wage component";
lab var oobetween 	"between detailed occupations log wage component";
lab var oototal 	"total log wage component (across detailed occupations)";

lab var soowithin 	"within sector-detailed-occupations log wage component";
lab var soobetween 	"between sector-detailed-occupations log wage component";
lab var soototal 	"total log wage component (across sector-detailed-occupations)";

lab var lwageyr9050	"Ratio 90:50 percentiles of log wages";
lab var lwageyr5010	"Ratio 50:10 percentiles of log wages";

lab var fswithin9050	"Ratio 90:50 percentiles of sector within component";
lab var fswithin5010	"Ratio 50:10 percentiles of sector within component";
lab var fsbetween9050	"Ratio 90:50 percentiles of sector between component";
lab var fsbetween5010	"Ratio 50:10 percentiles of sector between component";

lab var fowithin9050	"Ratio 90:50 percentiles of occupation within component";
lab var fowithin5010	"Ratio 50:10 percentiles of occupation within component";
lab var fobetween9050	"Ratio 90:50 percentiles of occupation between component";
lab var fobetween5010	"Ratio 50:10 percentiles of occupation between component";

lab var fsowithin9050	"Ratio 90:50 percentiles of sector-occupation within component";
lab var fsowithin5010	"Ratio 50:10 percentiles of sector-occupation within component";
lab var fsobetween9050	"Ratio 90:50 percentiles of sector-occupation between component";
lab var fsobetween5010	"Ratio 50:10 percentiles of sector-occupation between component";

local outvar="year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal;
sort year;
sa $data/sector-occupation/withinbetween-agmining-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

gen sdtotal=(stotal^0.5);

local vars1="swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";
local vars2="oowithin oobetween oototal soowithin soobetween soototal";
local vars3="lwageyr9050 lwageyr5010";

foreach var of varlist `vars1' `vars2' `vars3' sdtotal {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

***********************************;
**** Baseline Tables for Paper ****;
***********************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;
gen sh_oowithin=oowithin/oototal;
gen sh_soowithin=soowithin/soototal;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

********************************************************************;
**** Generates the Results in Table H1 in the Online Supplement ****;
********************************************************************;

**** Table H1 : Column (3), row (1), within component level, occupation 1994;

format sh_owithin %10.3f;
table data if year==1994, c(mean sh_owithin);

**** Table H1 : Column (3), row (2), within component level, sector 1994;

format sh_swithin %10.3f;
table data if year==1994, c(mean sh_swithin);

**** Table H1 : Column (3), row (3), within component level, sector-occupation 1994;

format sh_sowithin;
table data if year==1994, c(mean sh_sowithin);

**** Table H1 : Column (3), row (4), within component level, detailed occupation 1994;

format sh_oowithin %10.3f;
table data if year==1994, c(mean sh_oowithin);

**** Table H1 : Column (3), row (5), within component level, sector-detailed occupation 1994;

format sh_soowithin %10.3f;
table data if year==1994, c(mean sh_soowithin);

log close;
