
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*******************************************************************;
**** This file undertakes the regional robustness              ****;
**** test of the decomposition of overall wage inequality      ****;
**** into within and between sector-occupation components      ****;
**** in Table H2 of the online supplement (Columns (1) and (2) ****; 
**** for Sao Paulo only                                        ****;
*******************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

u $data/sector-occupation/sao-withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/sao-withinbetween-`yr'.dta;
};

lab var swithin 	"within sectors log wage component";
lab var sbetween 	"between sectors log wage component";
lab var stotal 		"total log wage component (across sectors)";

lab var owithin 	"within occupations log wage component";
lab var obetween 	"between occupations log wage component";
lab var ototal 		"total log wage component (across occupations)";

lab var sowithin 	"within sector-occupations log wage component";
lab var sobetween 	"between sector-occupations log wage component";
lab var sototal 	"total log wage component (across sector-occupations)";

lab var oowithin 	"within detailed occupations log wage component";
lab var oobetween 	"between detailed occupations log wage component";
lab var oototal 	"total log wage component (across detailed occupations)";

lab var soowithin 	"within sector-detailed-occupations log wage component";
lab var soobetween 	"between sector-detailed-occupations log wage component";
lab var soototal 	"total log wage component (across sector-detailed-occupations)";

lab var lwageyr9050	"Ratio 90:50 percentiles of log wages";
lab var lwageyr5010	"Ratio 50:10 percentiles of log wages";

lab var fswithin9050	"Ratio 90:50 percentiles of sector within component";
lab var fswithin5010	"Ratio 50:10 percentiles of sector within component";
lab var fsbetween9050	"Ratio 90:50 percentiles of sector between component";
lab var fsbetween5010	"Ratio 50:10 percentiles of sector between component";

lab var fowithin9050	"Ratio 90:50 percentiles of occupation within component";
lab var fowithin5010	"Ratio 50:10 percentiles of occupation within component";
lab var fobetween9050	"Ratio 90:50 percentiles of occupation between component";
lab var fobetween5010	"Ratio 50:10 percentiles of occupation between component";

lab var fsowithin9050	"Ratio 90:50 percentiles of sector-occupation within component";
lab var fsowithin5010	"Ratio 50:10 percentiles of sector-occupation within component";
lab var fsobetween9050	"Ratio 90:50 percentiles of sector-occupation between component";
lab var fsobetween5010	"Ratio 50:10 percentiles of sector-occupation between component";

local outvar="year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal;
sort year;
sa $data/sector-occupation/sao-withinbetween-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

local vars1="swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";
local vars2="oowithin oobetween oototal soowithin soobetween soototal";
local vars3="lwageyr9050 lwageyr5010";

foreach var of varlist `vars1' `vars2' `vars3' {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

***********************************;
**** Baseline Tables for Paper ****;
***********************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;
gen sh_oowithin=oowithin/oototal;
gen sh_soowithin=soowithin/soototal;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal oowithin oobetween oototal soowithin soobetween soototal {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_stotal86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ototal86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_sototal86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oototal86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soototal86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_stotal94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ototal94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_sototal94;
gen cnt_oowithin94=(sh_oowithin94*d_oowithin94)/d_oototal94;
gen cnt_soowithin94=(sh_soowithin94*d_soowithin94)/d_soototal94;

**** Decomposition of level of overall wage inequality 1994;
**** for Sao Paulo into within and between sector-occupation components;

**** Table H2, Column (1), Row (2);

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Decomposition of changes in overall wage inequality 1986-95;
**** for Sao Paulo into within and between sector-occupation components;

**** Table H2, Column (2), Row (2);

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

