
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

******************************************************************************;
**** This file decomposes overall wage inequality into within and between ****;
**** sector-occupation components                                         ****;
******************************************************************************;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/uncond/anova/anova-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

*******************************;
**** Merge FUNCEX new data ****;
*******************************;

so cnpj_radic firm_subsibge pis;
merge cnpj_radic using $data/funcex/expimp-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;

drop firm_indexp;

**************************;
* Variance Decomposition *;
**************************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Anova;

gen between=.;
gen betweenfirm=.;
gen betweenmeso=.;
gen within=.;
gen between_exp=.;
gen within_exp=.;
gen within_nonexp=.;
gen res_exp=.;
gen res_nonexp=.;
gen firm_exp=.;
gen firm_nonexp=.;
foreach sec of numlist 2(1)13 {;
display "Industry is";
display `sec';
foreach occ of numlist 1(1)5 {;
display "Occupation is";
display `occ';

* residual within-firm and between-firm components;
areg lwageyr if firm_subsibge==`sec'&occup==`occ', abs(cnpj_radic);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;

* decompose between-firm into within and between regions;
areg fbetween if firm_subsibge==`sec'&occup==`occ', abs(meso);
predict fbetweenfirm if e(sample), res;
predict fbetweenmeso if e(sample), xbd;

* overall variance decomposition;
egen temp=sd(fbetween), by(occup firm_subsibge);
replace temp = temp*temp;
replace between=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

egen temp=sd(fwithin), by(occup firm_subsibge);
replace temp=temp*temp;
replace within=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

* Do the results of the decomposition vary by type of firm;

egen temp1=sd(fwithin) if indexp==1, by(occup firm_subsibge);
egen temp2=max(temp1), by(occup firm_subsibge);
replace temp2=temp2*temp2;
replace res_exp=temp2 if firm_subsibge==`sec'&occup==`occ';
drop temp1 temp2;

egen temp1=sd(fwithin) if indexp==0, by(occup firm_subsibge);
egen temp2=max(temp1), by(occup firm_subsibge);
replace temp2=temp2*temp2;
replace res_nonexp=temp2 if firm_subsibge==`sec'&occup==`occ';
drop temp1 temp2;

egen temp1=sd(fbetween) if indexp==1, by(occup firm_subsibge);
egen temp2=max(temp1), by(occup firm_subsibge);
replace temp2=temp2*temp2;
replace firm_exp=temp2 if firm_subsibge==`sec'&occup==`occ';
drop temp1 temp2;

egen temp1=sd(fbetween) if indexp==0, by(occup firm_subsibge);
egen temp2=max(temp1), by(occup firm_subsibge);
replace temp2=temp2*temp2;
replace firm_nonexp=temp2 if firm_subsibge==`sec'&occup==`occ';
drop temp1 temp2;

* meso variance decomposition;
egen temp=sd(fbetweenfirm), by(occup firm_subsibge);
replace temp = temp*temp;
replace betweenfirm=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

egen temp=sd(fbetweenmeso), by(occup firm_subsibge);
replace temp = temp*temp;
replace betweenmeso=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

* within exporters, within nonexporters, and between exporters and nonexporters;
if `yr' >=1990 {;
areg fbetween if firm_subsibge==`sec'&occup==`occ', abs(indexp);
predict ewithin if e(sample), res;
predict ebetween if e(sample), xbd;

egen temp = sd(ebetween), by(occup firm_subsibge);
replace temp = temp*temp;
replace between_exp=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;

egen temp = sd(ewithin), by(occup firm_subsibge indexp);
replace temp = temp*temp;
replace within_exp=temp if firm_subsibge==`sec'&occup==`occ'&indexp==1;
replace within_nonexp=temp if firm_subsibge==`sec'&occup==`occ'&indexp==0;
drop temp;

drop ewithin;
drop ebetween;
};

drop fwithin;
drop fbetween;
drop fbetweenfirm;
drop fbetweenmeso;
};
};

gen total = within + between;
gen n_nonexp = 0; // for adjustment of 1/N in variance; 
replace n_nonexp = 1 if (indexp == 0);
rename indexp n_exp;

*************;
* Save Data *;
*************;

collapse (mean) within between betweenfirm betweenmeso between_exp within_exp within_nonexp res_exp res_nonexp firm_exp firm_nonexp total 
(sum) n_exp n_nonexp, by(occup firm_subsibge) fast;

* Within group vairances are constructed as 1/N_group rather than 1/N, so adjust to fix;
gen n = n_exp + n_nonexp;
replace within_exp = within_exp * n_exp / n;
replace within_nonexp = within_nonexp * n_nonexp / n;
drop n n_nonexp n_exp;

lab var within "unconditional within wage component";
lab var between "unconditional between wage component";
lab var total "total variance";
lab var betweenfirm "unconditional between within meso wage component";
lab var betweenmeso "unconditional between between meso wage component";
lab var between_exp "unconditional between wage component - between exporters component";
lab var within_exp "unconditional between wage component - within exporters component";
lab var within_nonexp "unconditional between wage component - within nonexporters component";
lab var res_exp "unconditional within wage component for exporters";
lab var res_nonexp "unconditional within wage component for non-exporters";
lab var firm_exp "unconditional between wage component for exporters";
lab var firm_nonexp "unconditional between wage component for non-exporters";

gen year=`yr';

so firm_subsibge occup year;
sa $data/uncond/anova/withinbetween-`yr'.dta,replace;

log close;

};

********************************************;
* Merge Within-Between Dispersion Datasets *;
********************************************;

#delimit;
u $data/uncond/anova/withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/uncond/anova/withinbetween-`yr'.dta;
};
so firm_subsibge occup year;
sa $data/uncond/anova/withinbetween-all.dta, replace;


